summaryrefslogtreecommitdiffstats
path: root/konversation/src/ircview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commitcecc781edbf5d505de14b8659f03b39f981cf283 (patch)
tree4830ff0d8a9e3bf779c88e73396544c3c5444521 /konversation/src/ircview.h
parent1b35f1baa94eb0b3869c0dadd5d467075370da3f (diff)
downloadkonversation-cecc781edbf5d505de14b8659f03b39f981cf283.tar.gz
konversation-cecc781edbf5d505de14b8659f03b39f981cf283.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/konversation@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'konversation/src/ircview.h')
-rw-r--r--konversation/src/ircview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/konversation/src/ircview.h b/konversation/src/ircview.h
index 50b7bce..3011a40 100644
--- a/konversation/src/ircview.h
+++ b/konversation/src/ircview.h
@@ -40,7 +40,7 @@ class IRCView : public KTextBrowser
TQ_OBJECT
public:
- IRCView(TQWidget* tqparent,Server* newServer);
+ IRCView(TQWidget* parent,Server* newServer);
~IRCView();
void clear();
@@ -231,7 +231,7 @@ class IRCView : public KTextBrowser
TQFontDatabase m_fontDataBase;
// Provide ability to disable tqparent ensureCursorVisible() call
bool m_disableEnsureCursorVisible;
// If this widget was painted at least once. Needed for scrollbar
// reset HACK as a precaution.
@@ -231,7 +231,7 @@ class IRCView : public KTextBrowser
TQFontDatabase m_fontDataBase;
- // Provide ability to disable tqparent ensureCursorVisible() call
+ // Provide ability to disable parent ensureCursorVisible() call
bool m_disableEnsureCursorVisible;
// If this widget was painted at least once. Needed for scrollbar